Learn R Programming

scitb (version 0.2.2)

Maddala.Cox.Snell: Maddala.Cox.Snell

Description

Maddala Cox Snell in the computational model.

Usage

Maddala.Cox.Snell(fit)

Value

Maddala Cox Snell.

#'@details The outcome variables in the model must be represented using 0 and 1. Among them, 1 represents the occurrence of the event.

Arguments

fit

Your model. Support logistic regression and Cox regression.

References

Riley RD, Ensor J, Snell KIE, Harrell FE, Martin GP, Reitsma JB, et al. Calculating the sample size required for developing a clinical prediction model. BMJ (Clinical research ed). 2020