Learn R Programming

scitb (version 0.2.2)

confnterval: confnterval

Description

P-values were inferred from confidence intervals.

Usage

confnterval(est = NULL, ratio = NULL, ul = NULL, ll = NULL)

Value

A list of results.

Arguments

est

Enter the effect value.

ratio

Effect ratio values. Includes OR,HR,RR.

ul

The upper limit of the credible interval.

ll

Lower limit of the credible interval.

Details

Limitations of the method:The formula for P is unreliable for very small P values and if your P value is smaller than 0.0001, just report it as P<0.0001.The methods described can be applied in a wide range of settings, including the results from meta-analysis and regression analyses. The main context where they are not correct is small samples where the outcome is continuous and the analysis has been done by a t test or analysis of variance, or the outcome is dichotomous and an exact method has been used for the confidence interval. However, even here the methods will be approximately correct in larger studies with, say, 60 patients or more.

References

Altman DG, Bland JM. How to obtain the P value from a confidence interval. BMJ. 2011;343:d2304. doi: 10.1136/bmj.d2304. PMID: 22803193.

Examples

Run this code
confnterval(est=0.05917381,ul=0.06756194,ll=0.05091284)


Run the code above in your browser using DataLab