Maddala Cox Snell in the computational model.
Maddala.Cox.Snell(fit)Maddala Cox Snell.
#'@details The outcome variables in the model must be represented using 0 and 1. Among them, 1 represents the occurrence of the event.
Your model. Support logistic regression and Cox regression.
Riley RD, Ensor J, Snell KIE, Harrell FE, Martin GP, Reitsma JB, et al. Calculating the sample size required for developing a clinical prediction model. BMJ (Clinical research ed). 2020